/v1/projects/{project_id}/dynamips/vms/{vm_id}/adapters/{adapter_number:d+}/ports/{port_number:d+}/stop_capture — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »

# /v1/projects/{project_id}/dynamips/vms/{vm_id}/adapters/{adapter_number:d+}/ports/{port_number:d+}/stop_capture

Contents

- /v1/projects/{project_id}/dynamips/vms/{vm_id}/adapters/{adapter_number:d+}/ports/{port_number:d+}/stop_capture
  - POST /v1/projects/{project_id}/dynamips/vms/{vm_id}/adapters/{adapter_number:d+}/ports/{port_number:d+}/stop_capture
    - Parameters
    - Response status codes

## POST /v1/projects/{project_id}/dynamips/vms/{vm_id}/adapters/{adapter_number:d+}/ports/{port_number:d+}/stop_capture

Stop a packet capture on a Dynamips VM instance

### Parameters

- project_id: UUID for the project
- port_number: Port on the adapter (always 0)
- adapter_number: Adapter to stop a packet capture
- vm_id: UUID for the instance

### Response status codes

- 400: Invalid request
- 404: Instance doesn’t exist
- 204: Capture stopped

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »